Module bdk_debug::blockchain::electrum
source · Available on crate feature
electrum only.Expand description
Electrum
This module defines a Blockchain struct that wraps an electrum_client::Client
and implements the logic required to populate the wallet’s database by
querying the inner client.
Example
let client = electrum_client::Client::new("ssl://electrum.blockstream.info:50002")?;
let blockchain = ElectrumBlockchain::from(client);Structs
- Wrapper over an Electrum Client that implements the required blockchain traits
- Configuration for an
ElectrumBlockchain