Module bdk_debug::descriptor
source · Expand description
Descriptors
This module contains generic utilities to work with descriptors, plus some re-exported types
from miniscript.
Re-exports
pub use self::checksum::calc_checksum;pub use self::error::Error as DescriptorError;pub use self::policy::Policy;
Modules
- Descriptor checksum
- Descriptor errors
- Descriptor policy
- Descriptor templates
Structs
- An extended key with origin, derivation path, and wildcard.
- Top-level script AST type
Enums
- Script descriptor
- The descriptor pubkey, either a single pubkey or an xpub.
- Legacy ScriptContext To be used as P2SH scripts For creation of Bare scriptpubkeys, construct the Miniscript under
BareScriptContext - Segwitv0 ScriptContext
- Whether a descriptor has a wildcard in it
Traits
- Trait implemented on
Descriptors to add a method to extract the spendingpolicy - Trait for types which can be converted into an
ExtendedDescriptorand aKeyMapusable by a wallet in a specificNetwork - The ScriptContext for Miniscript. Additional type information associated with miniscript that is used for carrying out checks that dependent on the context under which the script is used. For example, disallowing uncompressed keys in Segwit context
Type Definitions
- Alias for a
Descriptorthat contains extended derived keys - Alias for a
Descriptorthat can contain extended keys usingDescriptorPublicKey - Alias for the type of maps that represent derivation paths in a
psbt::Inputorpsbt::Output - Alias type for a map of public key to secret key
- Alias for the type of maps that represent taproot key origins in a
psbt::Inputorpsbt::Output