Descriptor checksum

This module contains a re-implementation of the function used by Bitcoin Core to calculate the checksum of a descriptor

Functions

  • Compute the checksum of a descriptor, excludes any existing checksum in the descriptor string from the calculation
  • Compute the checksum bytes of a descriptor, excludes any existing checksum in the descriptor string from the calculation
  • get_checksumDeprecated
    Compute the checksum of a descriptor
  • Compute the checksum bytes of a descriptor